@@ -1,10 +1,6 @@
-#include <sys/types.h>
-#include <sys/stat.h>
+#include <unistd.h>
 #include <pwd.h>
 #include "strerr.h"
-#include "buffer.h"
-#include "open.h"
-#include "readwrite.h"
 #include "exit.h"
 #include "auto_home.h"
 #include "generic-conf.h"
@@ -20,11 +16,6 @@ void usage(void)
 }
 
 char *dir;
-char *fn;
-char buf[1024];
-int fd;
-buffer ss;
-
 char *port;
 char *user;
 char *loguser;
