@@ -1,6 +1,6 @@
 #include "scan.h"
 
-unsigned int scan_long(register char *s,register long *i)
+unsigned int scan_long(register const char *s,register long *i)
 {
   int sign; unsigned long u; register unsigned int len;
   len = scan_plusminus(s,&sign); s += len;
