@@ -1,6 +1,6 @@
 #include "scan.h"
 
-unsigned int scan_plusminus(register char *s,register int *sign)
+unsigned int scan_plusminus(register const char *s,register int *sign)
 {
   if (*s == '+') { *sign = 1; return 1; }
   if (*s == '-') { *sign = -1; return 1; }
